==> haskell-reinterpret-cast-0.1.0-248-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reinterpret-cast
version:              0.1.0
visibility:           public
id:                   reinterpret-cast-0.1.0-7Xa722zK4DR9IsAceoj3ko
key:                  reinterpret-cast-0.1.0-7Xa722zK4DR9IsAceoj3ko
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/reinterpret-cast
synopsis:
    Memory reinterpretation casts for Float/Double and Word32/Word64

description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.

    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.

category:             Data
abi:                  5c8892e9b23c0f12e06ad3439b8c5be9
exposed:              True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI

import-dirs:          /usr/lib/ghc-9.2.8/site-local/reinterpret-cast-0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reinterpret-cast
hs-libraries:         HSreinterpret-cast-0.1.0-7Xa722zK4DR9IsAceoj3ko
depends:              array-0.5.4.0 base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock

haddock-html:         /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reinterpret-cast-0.1.0-276.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reinterpret-cast
version:              0.1.0
visibility:           public
id:                   reinterpret-cast-0.1.0-79v3w8O9rsk3yjconu7gD4
key:                  reinterpret-cast-0.1.0-79v3w8O9rsk3yjconu7gD4
license:              MIT
copyright:            2014 Niklas Hambüchen <mail@nh2.me>
maintainer:           Niklas Hambüchen <mail@nh2.me>
author:               Niklas Hambüchen <mail@nh2.me>
stability:            experimental
homepage:             https://github.com/nh2/reinterpret-cast
synopsis:
    Memory reinterpretation casts for Float/Double and Word32/Word64

description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.

    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.

category:             Data
abi:                  3262d35b86e5ed1fe1e8628c411dcdf7
exposed:              True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/reinterpret-cast-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/reinterpret-cast-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reinterpret-cast
hs-libraries:         HSreinterpret-cast-0.1.0-79v3w8O9rsk3yjconu7gD4
depends:              array-0.5.4.0 base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock

haddock-html:         /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
